@@ -21,13 +21,14 @@ Extended Documentation: https://doi-usgs.github.io/dataRetrieval")
 #'
 #' Retrieval functions for USGS and EPA hydrologic and water quality data.
 #'
-#' Please see \url{https://pubs.usgs.gov/publication/tm4A10} for more information.
+#' Please see \url{https://doi-usgs.github.io/dataRetrieval/} for more information.
 #'
 #' @name dataRetrieval
 #' @aliases dataRetrieval-package
 #' @docType package
 #' @author Laura De Cicco \email{ldecicco@@usgs.gov}
-NULL
+#' @keywords internal 
+"_PACKAGE"
 
 #' List of USGS parameter codes
 #'
